==> igniteui-react-charts-16.4.1.tgz: package/ES5/CalloutAnnotation_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { DependencyObject } from "igniteui-react-core/ES5/DependencyObject";
import { INotifyPropertyChanged_$type, PropertyChangedEventArgs, Type, Base, typeCast, markType } from "igniteui-react-core/ES5/type";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { Series } from "./Series";
import { Brush } from "igniteui-react-core/ES5/Brush";
import { Thickness } from "igniteui-react-core/ES5/Thickness";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
var CalloutAnnotation = /** @class */ (function (_super) {
    tslib_1.__extends(CalloutAnnotation, _super);
    function CalloutAnnotation() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.propertyChanged = null;
        _this.k = null;
        _this._formatLabel = null;
        _this.m = false;
        return _this;
    }
    CalloutAnnotation.prototype.an = function (a, b, c) {
        this.am(a, b, c);
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
    };
    CalloutAnnotation.prototype.am = function (a, b, c) {
        this.m = true;
    };
    Object.defineProperty(CalloutAnnotation.prototype, "formatLabel", {
        get: function () {
            return this._formatLabel;
        },
        set: function (a) {
            this._formatLabel = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CalloutAnnotation.prototype, "backgroundPadding", {
        get: function () {
            return new Thickness(1, this.backgroundPaddingLeft, this.backgroundPaddingTop, this.backgroundPaddingRight, this.backgroundPaddingBottom);
        },
        set: function (a) {
            this.backgroundPaddingLeft = a.c;
            this.backgroundPaddingTop = a.e;
            this.backgroundPaddingRight = a.d;
            this.backgroundPaddingBottom = a.b;
        },
        enumerable: true,
        configurable: true
    });
    CalloutAnnotation.$t = markType(CalloutAnnotation, 'CalloutAnnotation', DependencyObject.$, [INotifyPropertyChanged_$type]);
    return CalloutAnnotation;
}(DependencyObject));
export { CalloutAnnotation };
Type.dep(DependencyProperty, PropertyMetadata, CalloutAnnotation, 'an', ['BackgroundPaddingBottom', [1, NaN], 'BackgroundPaddingLeft', [1, NaN], 'BackgroundPaddingRight', [1, NaN], 'BackgroundPaddingTop', [1, NaN], 'Background', [Brush.$, null], 'Content', [4, null], 'Key', [4, null], 'LeaderBrush', [Brush.$, null], 'Outline', [Brush.$, null], 'Series', [Series.$, null], 'StrokeThickness', [1, 0], 'TextColor', [Brush.$, null], 'Text', [2, null], 'XValue', [4, 0], 'YValue', [4, 0]]);
var CalloutAnnotationWrapper = /** @class */ (function (_super) {
    tslib_1.__extends(CalloutAnnotationWrapper, _super);
    function CalloutAnnotationWrapper() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.c = null;
        return _this;
    }
    Object.defineProperty(CalloutAnnotationWrapper.prototype, "b", {
        get: function () {
            return this.a;
        },
        set: function (a) {
            this.a = a;
            this.a.k = this;
        },
        enumerable: true,
        configurable: true
    });
    CalloutAnnotationWrapper.prototype.equals = function (a) {
        var b = typeCast(CalloutAnnotationWrapper.$, a);
        if (b == null) {
            return _super.prototype.equals.call(this, a);
        }
        if (b.b == null && this.b == null) {
            return _super.prototype.equals.call(this, a);
        }
        if (b.b == null) {
            return false;
        }
        if (this.b.key != null || b.b.key != null) {
            return Base.equalsStatic(this.b.key, b.b.key);
        }
        return _super.prototype.equals.call(this, a);
    };
    CalloutAnnotationWrapper.prototype.getHashCode = function () {
        if (this.b == null || this.b.key == null) {
            return _super.prototype.getHashCode.call(this);
        }
        return Base.getHashCodeStatic(this.b.key);
    };
    CalloutAnnotationWrapper.$t = markType(CalloutAnnotationWrapper, 'CalloutAnnotationWrapper');
    return CalloutAnnotationWrapper;
}(Base));
export { CalloutAnnotationWrapper };
/*<BeginStatics Name="Infragistics.Controls.Charts.CalloutAnnotation" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.CalloutAnnotation" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES5/CalloutAnnotation_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { DependencyObject } from "igniteui-react-core/ES5/DependencyObject";
import { INotifyPropertyChanged_$type, Base, PropertyChangedEventArgs, Type, typeCast, markType } from "igniteui-react-core/ES5/type";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { Series } from "./Series";
import { Brush } from "igniteui-react-core/ES5/Brush";
import { Thickness } from "igniteui-react-core/ES5/Thickness";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
var CalloutAnnotation = /** @class */ (function (_super) {
    tslib_1.__extends(CalloutAnnotation, _super);
    function CalloutAnnotation() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.propertyChanged = null;
        _this.k = null;
        _this._formatLabel = null;
        _this.m = false;
        return _this;
    }
    CalloutAnnotation.prototype.an = function (a, b, c) {
        this.am(a, b, c);
        if (this.propertyChanged != null) {
            this.propertyChanged(this, new PropertyChangedEventArgs(a));
        }
    };
    CalloutAnnotation.prototype.am = function (a, b, c) {
        this.m = true;
    };
    Object.defineProperty(CalloutAnnotation.prototype, "formatLabel", {
        get: function () {
            return this._formatLabel;
        },
        set: function (a) {
            this._formatLabel = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CalloutAnnotation.prototype, "backgroundPadding", {
        get: function () {
            return new Thickness(1, this.backgroundPaddingLeft, this.backgroundPaddingTop, this.backgroundPaddingRight, this.backgroundPaddingBottom);
        },
        set: function (a) {
            this.backgroundPaddingLeft = a.c;
            this.backgroundPaddingTop = a.e;
            this.backgroundPaddingRight = a.d;
            this.backgroundPaddingBottom = a.b;
        },
        enumerable: true,
        configurable: true
    });
    CalloutAnnotation.$t = markType(CalloutAnnotation, 'CalloutAnnotation', DependencyObject.$, [INotifyPropertyChanged_$type]);
    return CalloutAnnotation;
}(DependencyObject));
export { CalloutAnnotation };
Type.dep(DependencyProperty, PropertyMetadata, CalloutAnnotation, 'an', ['BackgroundPaddingBottom', [1, NaN], 'BackgroundPaddingLeft', [1, NaN], 'BackgroundPaddingRight', [1, NaN], 'BackgroundPaddingTop', [1, NaN], 'Background', [Brush.$, null], 'Content', [4, null], 'Key', [4, null], 'LeaderBrush', [Brush.$, null], 'Outline', [Brush.$, null], 'Series', [Series.$, null], 'StrokeThickness', [1, 0], 'TextColor', [Brush.$, null], 'Text', [2, null], 'XValue', [4, 0], 'YValue', [4, 0]]);
var CalloutAnnotationWrapper = /** @class */ (function (_super) {
    tslib_1.__extends(CalloutAnnotationWrapper, _super);
    function CalloutAnnotationWrapper() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.a = null;
        _this.c = null;
        return _this;
    }
    Object.defineProperty(CalloutAnnotationWrapper.prototype, "b", {
        get: function () {
            return this.a;
        },
        set: function (a) {
            this.a = a;
            this.a.k = this;
        },
        enumerable: true,
        configurable: true
    });
    CalloutAnnotationWrapper.prototype.equals = function (a) {
        var b = typeCast(CalloutAnnotationWrapper.$, a);
        if (b == null) {
            return _super.prototype.equals.call(this, a);
        }
        if (b.b == null && this.b == null) {
            return _super.prototype.equals.call(this, a);
        }
        if (b.b == null) {
            return false;
        }
        if (this.b.key != null || b.b.key != null) {
            return Base.equalsStatic(this.b.key, b.b.key);
        }
        return _super.prototype.equals.call(this, a);
    };
    CalloutAnnotationWrapper.prototype.getHashCode = function () {
        if (this.b == null || this.b.key == null) {
            return _super.prototype.getHashCode.call(this);
        }
        return Base.getHashCodeStatic(this.b.key);
    };
    CalloutAnnotationWrapper.$t = markType(CalloutAnnotationWrapper, 'CalloutAnnotationWrapper');
    return CalloutAnnotationWrapper;
}(Base));
export { CalloutAnnotationWrapper };
